#
# spec file for package openobex
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           openobex
Version:        1.7.2
Release:        53.5
Summary:        Object Exchange (OBEX) Protocol
License:        GPL-2.0+ AND LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://openobex.sourceforge.net/
Source:         http://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}-Source.tar.gz
Patch1:         openobex-1.7.1-fix_udev_rules.patch
Patch2:         xopen-source.patch
BuildRequires:  bluez-devel
BuildRequires:  cmake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libusb-1_0-devel
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  xsltproc

%description
OBEX is a session protocol and can best be described as a binary HTTP
protocol. OBEX is optimized for ad-hoc wireless links and can be used
to exchange all kind of objects, like files, pictures, calendar entries
(vCal), and business cards (vCard).

%package -n libopenobex2
Summary:        Open Source Implementation of the Object Exchange (OBEX) Protocol
License:        GPL-2.0+ AND LGPL-2.1+
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{name} < %{version}-%{release}

%description -n libopenobex2
OBEX is a session protocol and can best be described as a binary HTTP
protocol. OBEX is optimized for ad-hoc wireless links and can be used
to exchange all kind of objects, like files, pictures, calendar entries
(vCal), and business cards (vCard).

%package apps
Summary:        Open Source Implementation of the Object Exchange (OBEX) Protocol
License:        GPL-2.0+ AND LGPL-2.1+
Group:          Productivity/Networking/Web/Utilities

%description apps
Various applications and ools using the Object Exchange (OBEX) Protocol libraries.

%package devel
Summary:        Development package for openobex
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libopenobex2 = %{version}

%description devel
Files needed for software development using openobex.

%prep
%setup -q -n openobex-%{version}-Source
%patch1 -p1
%patch2 -p1
# openobex runs some tests with g++
sed -i -e 's:openobex C:openobex C CXX:' CMakeLists.txt
# do not compile and install the udev part
sed -i    '/add_subdirectory.*udev/d' CMakeLists.txt
# doxygen no timestamp
sed -i -e '4 iHTML_TIMESTAMP=NO' doc/Doxyfile.in

%build
%cmake \
	-DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name}
make %{?_smp_mflags}
make %{?_smp_mflags} openobex-apps

%install
%cmake_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_docdir}
# don't ship obex_test program, that is for testing purposes only
# and has some problems (multiple buffer overflows etc.)
rm -f %{buildroot}%{_bindir}/obex_test
rm -f %{buildroot}%{_mandir}/man1/obex_test.1*

%post -n libopenobex2 -p /sbin/ldconfig
%postun -n libopenobex2 -p /sbin/ldconfig

%files -n libopenobex2
# NEWS is empty
%doc AUTHORS COPYING COPYING.LIB ChangeLog README
%{_libdir}/libopenobex.so.*

%files apps
%{_bindir}/ircp
%{_bindir}/irobex_palm3
%{_bindir}/irxfer
%{_bindir}/obex_find
%{_bindir}/obex_tcp
%{_mandir}/man1/*

%files devel
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/*
%{_includedir}/openobex/
%{_libdir}/libopenobex.so
%{_libdir}/pkgconfig/openobex.pc
%{_libdir}/cmake/OpenObex-%{version}/

%changelog
* Thu Jul  6 2017 jengelh@inai.de
- Fix RPM groups.
* Tue Jul  4 2017 tchvatal@suse.com
- Version update to 1.7.2:
  * Couple of tiny fixes
- Refresh patch xopen-source.patch
* Tue Aug 11 2015 schwab@suse.de
- xopen-source.patch: correct feature selection for getaddrinfo
* Tue Jun 23 2015 crrodriguez@opensuse.org
- Use libusb-1_0-devel as BuildRequires not libusb-devel
  as the old libusb compatibility layer is not used.
* Wed Aug 20 2014 acho@suse.com
- Added patches:
  * openobex-1.7.1-fix_udev_rules.patch
  Fixed 60-openobex.rules with 'TAG+="uaccess"' (bnc#858863)
* Tue Jun 24 2014 jmatejek@suse.com
- drop udev rules, obsolete/provide openobex from libopenobex again
  (group plugdev doesn't exist anymore and it's unclear how to replace it,
  so the udev rules are virtually useless)
  this fixes bnc#865429
* Sat Jun 21 2014 tchvatal@suse.com
- Generate manpages and doxyfiles.
- Use cmake macros and fix project definition to work with them
- Cleanup with spec-cleaner
* Sun Dec  8 2013 crrodriguez@opensuse.org
- Use distribution definition of _udevrulesdir instead of rules_dir
- run %%udev_rules_update if such macro is defined.
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 1.7.1:
  + Add OBEX_FL_STREAM_CONTINUE.
  + Several fixes.
- Changes from version 1.7:
  + Add support for CMake config files
  + Internal code reorganisation and rewrite
  + Add new function set for better control than
    OBEX_HandleInput(): OBEX_SetTimeout(), OBEX_Work() and
    OBEX_GetDataDirection()
- Changes from version 1.6:
  + Change ABI from 1 to 2 because:
  - Redo the USB changes from version 1.4.
  - Remove InOBEX_* function, use the TcpOBEX_* functions
    instead.
  - Remove the simple Unicode<->ASCII functions.
  + Add support for Single Response Mode.
  + Add manpages for all example applications.
  + Add udev support.
  + Add new example app to find IrDA and USB OBEX devices.
  + Add fixes for FreeBSD.
  + Add support for libusb-1.x.
  + Add support for close-on-exec.
- Drop upstream fixed patches:
  + openobex-libusb-check.patch.
  + openobex-1.3-pkgconfig.patch (done slightly different).
  + 0001-fix-fd-leak.patch.
- No longer provide and obsolete openobex from the library package:
  the main package now contains udev rules and helpers.
- Require openobex from the library package: an app making use of
  the library surely wants the udev helpers in place.
- Rename libopenobex1 subpackage to libopenobex2, following
  upstreams soname change.
- Require libopenobex2 from the -devel package instead of the main
  package (the name used to be provided by libopenobex1).
- Replace libtool BuildRequires with cmake, following upstreams
  build system switch.
- Add pkgconfig(udev) BuildRequires: needed to build the udev
  helper as well to find the location where to install udev rules
  (define rules_dir).
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Mar  6 2013 coolo@suse.com
- update license to new format
* Fri May 25 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Fri Mar 26 2010 vuntz@opensuse.org
- Update to version 1.5:
  + Revert USB changes that broke the ABI.
  + Add more documentation and update manual pages.
  + Add missing files to distribution.
  + Fix obex_object_resume for server side role.
  + Fix security issue when creating file.
- Changes from version 1.4:
  + Add OBEX_ObjectGetSpace function.
  + Add OBEX_ObjectGetCommand function.
  + Add Bluetooth support for FreeBSD and NetBSD.
  + Add support for using OBEX over IPv6.
  + Add support for Win32 platform.
  + Fix support for document generation.
  + Fix public visible symbols of the libraries.
  + Fix handling of unexpected data from the server.
  + Fix return value interpretation of obex_object_send.
  + Fix obex_object_resume handling if sending fails.
  + Allow suspending before the first packet has been sent.
- Remove glib2-devel BuildRequires, do not use --enable-glib
  configure flag and drop glib-related subpackages: this is not
  built anymore in the tarball.
- Drop openobex-svn.patch: fixed upstream.
- Rebase openobex-libusb-check.patch, openobex-1.3-pkgconfig.patch
  and 0001-fix-fd-leak.patch.
- Move the library to a libopenobex1 subpackage that
  provides/obsoletes openobex (since the old package only contained
  the library).
* Sun Nov 15 2009 meissner@suse.de
- apply patches with fuzz-0
* Sat Oct 10 2009 crrodriguez@opensuse.org
- openobex-1.3-159.15: missing call to closedir [bnc#544452]
* Mon Mar 23 2009 crrodriguez@suse.de
- fix pkgconfig file
* Mon Feb 23 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel package deps
- run ldconfig correctly
* Tue Sep 16 2008 ro@suse.de
- fix requires for devel package
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Fri May 18 2007 olh@suse.de
- -devel package requires libusb-devel
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Mon Apr 30 2007 sbrabec@suse.cz
- Updated to current SVN version (#220448):
  * Provides openobex-glib bindings.
  * Library build fixes.
  * Minor fixes.
* Tue Dec 19 2006 cstender@suse.de
- added libusb to openobex-devel Requires.
* Sat Oct 14 2006 dgollub@suse.de
- added libusb to BuildRequires to get direct USB support.
* Mon Oct  9 2006 mskibbe@suse.de
- add applications to subpackage
* Tue Jun 27 2006 cthiel@suse.de
- update to version 1.3
  * Add support for setting the creation-ID.
  * Updated constants to match IrOBEX 1.3.
  * Replace netbuf implementation with databuffer.
  * Fix segmentation fault when receiving invalid OBEX packets.
* Sun Apr 23 2006 cthiel@suse.de
- update to version 1.2
  * Add OBEX_EV_REQCHECK support.
  * Add support for suspend after sending a header.
  * Add support for empty headers for buggy OBEX servers.
  * Fix memory leak in obex_object_send().
- changes in version 1.1
  * Fix list of exported functions (Bug 644690).
  * Fix duplicate string from basename() result (Bug 668977).
  * Fix wrong order of sanity checks (Bug 703452).
  * Fix memory leak in send_stream() function.
  * ISO C99 says that inttypes.h includes stdint.h header.
  * Add proper client side ABORT support.
  * Add support for OBEX_SuspendRequest() and OBEX_ResumeRequest().
  * Add USB transport support.
  * Increase the allowed maximum MTU to 64kB-1.
  * Disconnect when an ABORT fails.
  * Make it possible to include headers from C++ source code.
  * Advertise OBEX Protocol Version 1.0.
- dropped openobex.diff
- dropped openobex-serveraccept-export.patch
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Aug 23 2005 hvogel@suse.de
- added `OBEX_ServerAccept' to the exported symbols
* Sat Oct 23 2004 hvogel@suse.de
- move config script to the devel package
* Mon Jan 26 2004 hvogel@suse.de
- move devel stuff into subpackage
* Fri Nov 21 2003 adrian@suse.de
- make so-name compatible with version 1.0.0
* Fri Nov 21 2003 hvogel@suse.de
- update to version 1.0.1
* Mon Aug 11 2003 mmj@suse.de
- Invoke autoreconf to build on all archs
* Thu Aug  7 2003 hvogel@suse.de
- Initial Package, Version 1.0.0
